matrixpls method for generic function residuals computes the residual
covariance matrix and various fit indices presented by Lohmöller (1989, ch 2.4)## S3 method for class 'matrixpls':
residuals(object, ...)matrixpls function.inner, outer, and indices elements
containing the residual covariance matrix of regressions of composites on other composites,
the residual covariance matrix of indicators on composites, and various fit indices
calculated based on the residuals.Henseler, J., Dijkstra, T. K., Sarstedt, M., Ringle, C. M., Diamantopoulos, A., Straub, D. W., … Calantone, R. J. (2014). Common Beliefs and Reality About PLS Comments on Rönkkö and Evermann (2013). Organizational Research Methods, 17(2), 182–209. doi:10.1177/1094428114526928
AVE;
CR; GoF; R2;
effects.matrixpls;
loadings.matrixpls;
predict.matrixpls